@@ -1,18 +1,17 @@
 """Factory for creating backends."""
 
-from typing import Callable, Optional, Union
+from typing import Union
 
 from pydantic import BaseModel
-from wish_models import LogFiles
 
 from wish_command_execution.backend.base import Backend
 from wish_command_execution.backend.bash import BashBackend
+from wish_command_execution.backend.sliver import SliverBackend
 
 
 class BashConfig(BaseModel):
     """Configuration for bash backend."""
     shell_path: str = "/bin/bash"
-    log_summarizer: Optional[Callable[[LogFiles], str]] = None
 
 
 class SliverConfig(BaseModel):
@@ -31,9 +30,8 @@ def create_backend(config: Union[BashConfig, SliverConfig]) -> Backend:
         A backend instance.
     """
     if isinstance(config, BashConfig):
-        return BashBackend(log_summarizer=config.log_summarizer)
+        return BashBackend()
     elif isinstance(config, SliverConfig):
-        # Future implementation
-        raise NotImplementedError("Sliver backend not implemented yet")
+        return SliverBackend(config.session_id, config.client_config_path)
     else:
         raise ValueError(f"Unsupported backend configuration: {type(config)}")
